Class: Google::Apis::VaultV1::HeldAccount

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vault_v1/classes.rb,
lib/google/apis/vault_v1/representations.rb,
lib/google/apis/vault_v1/representations.rb

Overview

An account covered by a hold. This structure is immutable. It can be an individual account or a Google Group, depending on the service. To work with Vault resources, the account must have the required Vault privileges and access to the matter. To access a matter, the account must have created the matter, have the matter shared with them, or have the View All Matters privilege.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HeldAccount

Returns a new instance of HeldAccount.



1041
1042
1043
# File 'lib/google/apis/vault_v1/classes.rb', line 1041

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

The account ID, as provided by the Admin SDK. Corresponds to the JSON property accountId

Returns:

  • (String)


1018
1019
1020
# File 'lib/google/apis/vault_v1/classes.rb', line 1018

def 
  @account_id
end

#emailString

The primary email address of the account. If used as an input, this takes precedence over accountId. Corresponds to the JSON property email

Returns:

  • (String)


1024
1025
1026
# File 'lib/google/apis/vault_v1/classes.rb', line 1024

def email
  @email
end

#first_nameString

Output only. The first name of the account holder. Corresponds to the JSON property firstName

Returns:

  • (String)


1029
1030
1031
# File 'lib/google/apis/vault_v1/classes.rb', line 1029

def first_name
  @first_name
end

#hold_timeString

Output only. When the account was put on hold. Corresponds to the JSON property holdTime

Returns:

  • (String)


1034
1035
1036
# File 'lib/google/apis/vault_v1/classes.rb', line 1034

def hold_time
  @hold_time
end

#last_nameString

Output only. The last name of the account holder. Corresponds to the JSON property lastName

Returns:

  • (String)


1039
1040
1041
# File 'lib/google/apis/vault_v1/classes.rb', line 1039

def last_name
  @last_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1046
1047
1048
1049
1050
1051
1052
# File 'lib/google/apis/vault_v1/classes.rb', line 1046

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @email = args[:email] if args.key?(:email)
  @first_name = args[:first_name] if args.key?(:first_name)
  @hold_time = args[:hold_time] if args.key?(:hold_time)
  @last_name = args[:last_name] if args.key?(:last_name)
end