Class: Google::Apis::VaultV1::HeldDriveQuery

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vault_v1/classes.rb,
lib/google/apis/vault_v1/representations.rb,
lib/google/apis/vault_v1/representations.rb

Overview

Options for Drive holds.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HeldDriveQuery

Returns a new instance of HeldDriveQuery.



1078
1079
1080
# File 'lib/google/apis/vault_v1/classes.rb', line 1078

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#include_shared_drive_filesBoolean Also known as: include_shared_drive_files?

To include files in shared drives in the hold, set to true. Corresponds to the JSON property includeSharedDriveFiles

Returns:

  • (Boolean)


1069
1070
1071
# File 'lib/google/apis/vault_v1/classes.rb', line 1069

def include_shared_drive_files
  @include_shared_drive_files
end

#include_team_drive_filesBoolean Also known as: include_team_drive_files?

To include files in Team Drives in the hold, set to true. Corresponds to the JSON property includeTeamDriveFiles

Returns:

  • (Boolean)


1075
1076
1077
# File 'lib/google/apis/vault_v1/classes.rb', line 1075

def include_team_drive_files
  @include_team_drive_files
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1083
1084
1085
1086
# File 'lib/google/apis/vault_v1/classes.rb', line 1083

def update!(**args)
  @include_shared_drive_files = args[:include_shared_drive_files] if args.key?(:include_shared_drive_files)
  @include_team_drive_files = args[:include_team_drive_files] if args.key?(:include_team_drive_files)
end