Class: Google::Apis::VaultV1::Hold

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vault_v1/classes.rb,
lib/google/apis/vault_v1/representations.rb,
lib/google/apis/vault_v1/representations.rb

Overview

A hold. A hold prevents the specified Google Workspace service from purging data for specific accounts or all members of an organizational unit. To work with Vault resources, the account must have the required Vault privileges and access to the matter. To access a matter, the account must have created the matter, have the matter shared with them, or have the View All Matters privilege.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Hold

Returns a new instance of Hold.



1287
1288
1289
# File 'lib/google/apis/vault_v1/classes.rb', line 1287

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accountsArray<Google::Apis::VaultV1::HeldAccount>

If set, the hold applies to the specified accounts and orgUnit must be empty. Corresponds to the JSON property accounts



1255
1256
1257
# File 'lib/google/apis/vault_v1/classes.rb', line 1255

def accounts
  @accounts
end

#corpusString

The service to be searched. Corresponds to the JSON property corpus

Returns:

  • (String)


1260
1261
1262
# File 'lib/google/apis/vault_v1/classes.rb', line 1260

def corpus
  @corpus
end

#hold_idString

The unique immutable ID of the hold. Assigned during creation. Corresponds to the JSON property holdId

Returns:

  • (String)


1265
1266
1267
# File 'lib/google/apis/vault_v1/classes.rb', line 1265

def hold_id
  @hold_id
end

#nameString

The name of the hold. Corresponds to the JSON property name

Returns:

  • (String)


1270
1271
1272
# File 'lib/google/apis/vault_v1/classes.rb', line 1270

def name
  @name
end

#org_unitGoogle::Apis::VaultV1::HeldOrgUnit

The organizational unit covered by a hold. This structure is immutable. Corresponds to the JSON property orgUnit



1275
1276
1277
# File 'lib/google/apis/vault_v1/classes.rb', line 1275

def org_unit
  @org_unit
end

#queryGoogle::Apis::VaultV1::CorpusQuery

Service-specific options for holds. Corresponds to the JSON property query



1280
1281
1282
# File 'lib/google/apis/vault_v1/classes.rb', line 1280

def query
  @query
end

#update_timeString

The last time this hold was modified. Corresponds to the JSON property updateTime

Returns:

  • (String)


1285
1286
1287
# File 'lib/google/apis/vault_v1/classes.rb', line 1285

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1292
1293
1294
1295
1296
1297
1298
1299
1300
# File 'lib/google/apis/vault_v1/classes.rb', line 1292

def update!(**args)
  @accounts = args[:accounts] if args.key?(:accounts)
  @corpus = args[:corpus] if args.key?(:corpus)
  @hold_id = args[:hold_id] if args.key?(:hold_id)
  @name = args[:name] if args.key?(:name)
  @org_unit = args[:org_unit] if args.key?(:org_unit)
  @query = args[:query] if args.key?(:query)
  @update_time = args[:update_time] if args.key?(:update_time)
end