Class: Google::Apis::VaultV1::ListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vault_v1/classes.rb,
lib/google/apis/vault_v1/representations.rb,
lib/google/apis/vault_v1/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOperationsResponse

Returns a new instance of ListOperationsResponse.



1401
1402
1403
# File 'lib/google/apis/vault_v1/classes.rb', line 1401

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1386
1387
1388
# File 'lib/google/apis/vault_v1/classes.rb', line 1386

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::VaultV1::Operation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



1391
1392
1393
# File 'lib/google/apis/vault_v1/classes.rb', line 1391

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1399
1400
1401
# File 'lib/google/apis/vault_v1/classes.rb', line 1399

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1406
1407
1408
1409
1410
# File 'lib/google/apis/vault_v1/classes.rb', line 1406

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end