Class: Google::Apis::VaultV1::Matter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vault_v1/classes.rb,
lib/google/apis/vault_v1/representations.rb,
lib/google/apis/vault_v1/representations.rb

Overview

Represents a matter. To work with Vault resources, the account must have the required Vault privileges and access to the matter. To access a matter, the account must have created the matter, have the matter shared with them, or have the View All Matters privilege.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Matter

Returns a new instance of Matter.



1611
1612
1613
# File 'lib/google/apis/vault_v1/classes.rb', line 1611

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

An optional description for the matter. Corresponds to the JSON property description

Returns:

  • (String)


1582
1583
1584
# File 'lib/google/apis/vault_v1/classes.rb', line 1582

def description
  @description
end

#matter_idString

The matter ID, which is generated by the server. Leave blank when creating a matter. Corresponds to the JSON property matterId

Returns:

  • (String)


1588
1589
1590
# File 'lib/google/apis/vault_v1/classes.rb', line 1588

def matter_id
  @matter_id
end

#matter_permissionsArray<Google::Apis::VaultV1::MatterPermission>

Lists the users and their permission for the matter. Currently there is no programmer defined limit on the number of permissions a matter can have. Corresponds to the JSON property matterPermissions



1594
1595
1596
# File 'lib/google/apis/vault_v1/classes.rb', line 1594

def matter_permissions
  @matter_permissions
end

#matter_regionString

Optional. The requested data region for the matter. Corresponds to the JSON property matterRegion

Returns:

  • (String)


1599
1600
1601
# File 'lib/google/apis/vault_v1/classes.rb', line 1599

def matter_region
  @matter_region
end

#nameString

The name of the matter. Corresponds to the JSON property name

Returns:

  • (String)


1604
1605
1606
# File 'lib/google/apis/vault_v1/classes.rb', line 1604

def name
  @name
end

#stateString

The state of the matter. Corresponds to the JSON property state

Returns:

  • (String)


1609
1610
1611
# File 'lib/google/apis/vault_v1/classes.rb', line 1609

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1616
1617
1618
1619
1620
1621
1622
1623
# File 'lib/google/apis/vault_v1/classes.rb', line 1616

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @matter_id = args[:matter_id] if args.key?(:matter_id)
  @matter_permissions = args[:matter_permissions] if args.key?(:matter_permissions)
  @matter_region = args[:matter_region] if args.key?(:matter_region)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end