Class: Google::Apis::VaultV1::Query
- Inherits:
-
Object
- Object
- Google::Apis::VaultV1::Query
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vault_v1/classes.rb,
lib/google/apis/vault_v1/representations.rb,
lib/google/apis/vault_v1/representations.rb
Overview
The query definition used for search and export.
Instance Attribute Summary collapse
-
#account_info ⇒ Google::Apis::VaultV1::AccountInfo
The accounts to search Corresponds to the JSON property
accountInfo. -
#calendar_options ⇒ Google::Apis::VaultV1::CalendarOptions
Additional options for Calendar search Corresponds to the JSON property
calendarOptions. -
#corpus ⇒ String
The Google Workspace service to search.
-
#data_scope ⇒ String
The data source to search.
-
#drive_document_info ⇒ Google::Apis::VaultV1::DriveDocumentInfo
The Drive documents to search.
-
#drive_options ⇒ Google::Apis::VaultV1::DriveOptions
Additional options for Drive search.
-
#end_time ⇒ String
The end time for the search query.
-
#gemini_options ⇒ Google::Apis::VaultV1::GeminiOptions
Additional options for Gemini search Corresponds to the JSON property
geminiOptions. -
#hangouts_chat_info ⇒ Google::Apis::VaultV1::HangoutsChatInfo
The Chat spaces to search Corresponds to the JSON property
hangoutsChatInfo. -
#hangouts_chat_options ⇒ Google::Apis::VaultV1::HangoutsChatOptions
Additional options for Google Chat search Corresponds to the JSON property
hangoutsChatOptions. -
#mail_options ⇒ Google::Apis::VaultV1::MailOptions
Additional options for Gmail search Corresponds to the JSON property
mailOptions. -
#method_prop ⇒ String
The entity to search.
-
#org_unit_info ⇒ Google::Apis::VaultV1::OrgUnitInfo
The organizational unit to search Corresponds to the JSON property
orgUnitInfo. -
#search_method ⇒ String
The search method to use.
-
#shared_drive_info ⇒ Google::Apis::VaultV1::SharedDriveInfo
The shared drives to search Corresponds to the JSON property
sharedDriveInfo. -
#sites_url_info ⇒ Google::Apis::VaultV1::SitesUrlInfo
The published site URLs of new Google Sites to search Corresponds to the JSON property
sitesUrlInfo. -
#start_time ⇒ String
The start time for the search query.
-
#team_drive_info ⇒ Google::Apis::VaultV1::TeamDriveInfo
Team Drives to search Corresponds to the JSON property
teamDriveInfo. -
#terms ⇒ String
Service-specific search operators to filter search results.
-
#time_zone ⇒ String
The time zone name.
-
#voice_options ⇒ Google::Apis::VaultV1::VoiceOptions
Additional options for Voice search Corresponds to the JSON property
voiceOptions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Query
constructor
A new instance of Query.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Query
Returns a new instance of Query.
1854 1855 1856 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1854 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_info ⇒ Google::Apis::VaultV1::AccountInfo
The accounts to search
Corresponds to the JSON property accountInfo
1743 1744 1745 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1743 def account_info @account_info end |
#calendar_options ⇒ Google::Apis::VaultV1::CalendarOptions
Additional options for Calendar search
Corresponds to the JSON property calendarOptions
1748 1749 1750 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1748 def @calendar_options end |
#corpus ⇒ String
The Google Workspace service to search.
Corresponds to the JSON property corpus
1753 1754 1755 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1753 def corpus @corpus end |
#data_scope ⇒ String
The data source to search.
Corresponds to the JSON property dataScope
1758 1759 1760 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1758 def data_scope @data_scope end |
#drive_document_info ⇒ Google::Apis::VaultV1::DriveDocumentInfo
The Drive documents to search.
Corresponds to the JSON property driveDocumentInfo
1763 1764 1765 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1763 def drive_document_info @drive_document_info end |
#drive_options ⇒ Google::Apis::VaultV1::DriveOptions
Additional options for Drive search.
Corresponds to the JSON property driveOptions
1768 1769 1770 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1768 def @drive_options end |
#end_time ⇒ String
The end time for the search query. Specify in GMT. The value is rounded to 12
AM on the specified date.
Corresponds to the JSON property endTime
1774 1775 1776 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1774 def end_time @end_time end |
#gemini_options ⇒ Google::Apis::VaultV1::GeminiOptions
Additional options for Gemini search
Corresponds to the JSON property geminiOptions
1779 1780 1781 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1779 def @gemini_options end |
#hangouts_chat_info ⇒ Google::Apis::VaultV1::HangoutsChatInfo
The Chat spaces to search
Corresponds to the JSON property hangoutsChatInfo
1784 1785 1786 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1784 def hangouts_chat_info @hangouts_chat_info end |
#hangouts_chat_options ⇒ Google::Apis::VaultV1::HangoutsChatOptions
Additional options for Google Chat search
Corresponds to the JSON property hangoutsChatOptions
1789 1790 1791 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1789 def @hangouts_chat_options end |
#mail_options ⇒ Google::Apis::VaultV1::MailOptions
Additional options for Gmail search
Corresponds to the JSON property mailOptions
1794 1795 1796 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1794 def @mail_options end |
#method_prop ⇒ String
The entity to search. This field replaces searchMethod to support shared
drives. When searchMethod is TEAM_DRIVE, the response of this field is
SHARED_DRIVE.
Corresponds to the JSON property method
1801 1802 1803 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1801 def method_prop @method_prop end |
#org_unit_info ⇒ Google::Apis::VaultV1::OrgUnitInfo
The organizational unit to search
Corresponds to the JSON property orgUnitInfo
1806 1807 1808 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1806 def org_unit_info @org_unit_info end |
#search_method ⇒ String
The search method to use.
Corresponds to the JSON property searchMethod
1811 1812 1813 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1811 def search_method @search_method end |
#shared_drive_info ⇒ Google::Apis::VaultV1::SharedDriveInfo
The shared drives to search
Corresponds to the JSON property sharedDriveInfo
1816 1817 1818 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1816 def shared_drive_info @shared_drive_info end |
#sites_url_info ⇒ Google::Apis::VaultV1::SitesUrlInfo
The published site URLs of new Google Sites to search
Corresponds to the JSON property sitesUrlInfo
1821 1822 1823 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1821 def sites_url_info @sites_url_info end |
#start_time ⇒ String
The start time for the search query. Specify in GMT. The value is rounded to
12 AM on the specified date.
Corresponds to the JSON property startTime
1827 1828 1829 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1827 def start_time @start_time end |
#team_drive_info ⇒ Google::Apis::VaultV1::TeamDriveInfo
Team Drives to search
Corresponds to the JSON property teamDriveInfo
1832 1833 1834 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1832 def team_drive_info @team_drive_info end |
#terms ⇒ String
Service-specific search operators to filter search results.
Corresponds to the JSON property terms
1838 1839 1840 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1838 def terms @terms end |
#time_zone ⇒ String
The time zone name. It should be an IANA TZ name, such as "America/Los_Angeles"
. For a list of time zone names, see Time Zone. For more information about how Vault uses
time zones, see the Vault help center.
Corresponds to the JSON property timeZone
1847 1848 1849 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1847 def time_zone @time_zone end |
#voice_options ⇒ Google::Apis::VaultV1::VoiceOptions
Additional options for Voice search
Corresponds to the JSON property voiceOptions
1852 1853 1854 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1852 def @voice_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1859 def update!(**args) @account_info = args[:account_info] if args.key?(:account_info) @calendar_options = args[:calendar_options] if args.key?(:calendar_options) @corpus = args[:corpus] if args.key?(:corpus) @data_scope = args[:data_scope] if args.key?(:data_scope) @drive_document_info = args[:drive_document_info] if args.key?(:drive_document_info) @drive_options = args[:drive_options] if args.key?(:drive_options) @end_time = args[:end_time] if args.key?(:end_time) @gemini_options = args[:gemini_options] if args.key?(:gemini_options) @hangouts_chat_info = args[:hangouts_chat_info] if args.key?(:hangouts_chat_info) @hangouts_chat_options = args[:hangouts_chat_options] if args.key?(:hangouts_chat_options) @mail_options = args[:mail_options] if args.key?(:mail_options) @method_prop = args[:method_prop] if args.key?(:method_prop) @org_unit_info = args[:org_unit_info] if args.key?(:org_unit_info) @search_method = args[:search_method] if args.key?(:search_method) @shared_drive_info = args[:shared_drive_info] if args.key?(:shared_drive_info) @sites_url_info = args[:sites_url_info] if args.key?(:sites_url_info) @start_time = args[:start_time] if args.key?(:start_time) @team_drive_info = args[:team_drive_info] if args.key?(:team_drive_info) @terms = args[:terms] if args.key?(:terms) @time_zone = args[:time_zone] if args.key?(:time_zone) @voice_options = args[:voice_options] if args.key?(:voice_options) end |