Class: Google::Apis::VaultV1::DriveOptions
- Inherits:
-
Object
- Object
- Google::Apis::VaultV1::DriveOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vault_v1/classes.rb,
lib/google/apis/vault_v1/representations.rb,
lib/google/apis/vault_v1/representations.rb
Overview
Additional options for Drive search.
Instance Attribute Summary collapse
-
#client_side_encrypted_option ⇒ String
Set whether the results include only content encrypted with Google Workspace Client-side encryption content, only unencrypted content, or both.
-
#include_shared_drives ⇒ Boolean
(also: #include_shared_drives?)
Set to true to include shared drives.
-
#include_team_drives ⇒ Boolean
(also: #include_team_drives?)
Set to true to include Team Drive.
-
#shared_drives_option ⇒ String
Optional.
-
#version_date ⇒ String
Search the current version of the Drive file, but export the contents of the last version saved before 12:00 AM UTC on the specified date.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DriveOptions
constructor
A new instance of DriveOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DriveOptions
Returns a new instance of DriveOptions.
636 637 638 |
# File 'lib/google/apis/vault_v1/classes.rb', line 636 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_side_encrypted_option ⇒ String
Set whether the results include only content encrypted with Google Workspace
Client-side encryption content, only
unencrypted content, or both. Defaults to both. Currently supported for Drive.
Corresponds to the JSON property clientSideEncryptedOption
608 609 610 |
# File 'lib/google/apis/vault_v1/classes.rb', line 608 def client_side_encrypted_option @client_side_encrypted_option end |
#include_shared_drives ⇒ Boolean Also known as:
Set to true to include shared drives.
Corresponds to the JSON property includeSharedDrives
613 614 615 |
# File 'lib/google/apis/vault_v1/classes.rb', line 613 def include_shared_drives @include_shared_drives end |
#include_team_drives ⇒ Boolean Also known as: include_team_drives?
Set to true to include Team Drive.
Corresponds to the JSON property includeTeamDrives
619 620 621 |
# File 'lib/google/apis/vault_v1/classes.rb', line 619 def include_team_drives @include_team_drives end |
#shared_drives_option ⇒ String
Optional. Options to include or exclude documents in shared drives. We
recommend using this field over include_shared_drives. This field overrides
include_shared_drives and include_team_drives when set.
Corresponds to the JSON property sharedDrivesOption
627 628 629 |
# File 'lib/google/apis/vault_v1/classes.rb', line 627 def shared_drives_option @shared_drives_option end |
#version_date ⇒ String
Search the current version of the Drive file, but export the contents of the
last version saved before 12:00 AM UTC on the specified date. Enter the date
in UTC.
Corresponds to the JSON property versionDate
634 635 636 |
# File 'lib/google/apis/vault_v1/classes.rb', line 634 def version_date @version_date end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
641 642 643 644 645 646 647 |
# File 'lib/google/apis/vault_v1/classes.rb', line 641 def update!(**args) @client_side_encrypted_option = args[:client_side_encrypted_option] if args.key?(:client_side_encrypted_option) @include_shared_drives = args[:include_shared_drives] if args.key?(:include_shared_drives) @include_team_drives = args[:include_team_drives] if args.key?(:include_team_drives) @shared_drives_option = args[:shared_drives_option] if args.key?(:shared_drives_option) @version_date = args[:version_date] if args.key?(:version_date) end |