Class: Google::Apis::VaultV1::GroupsCountResult
- Inherits:
-
Object
- Object
- Google::Apis::VaultV1::GroupsCountResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vault_v1/classes.rb,
lib/google/apis/vault_v1/representations.rb,
lib/google/apis/vault_v1/representations.rb
Overview
Groups specific count metrics.
Instance Attribute Summary collapse
-
#account_count_errors ⇒ Array<Google::Apis::VaultV1::AccountCountError>
Error occurred when querying these accounts.
-
#account_counts ⇒ Array<Google::Apis::VaultV1::AccountCount>
Subtotal count per matching account that have more than zero messages.
-
#matching_accounts_count ⇒ Fixnum
Total number of accounts that can be queried and have more than zero messages.
-
#non_queryable_accounts ⇒ Array<String>
When DataScope is HELD_DATA, these accounts in the request are not queried because they are not on hold.
-
#queried_accounts_count ⇒ Fixnum
Total number of accounts involved in this count operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GroupsCountResult
constructor
A new instance of GroupsCountResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GroupsCountResult
Returns a new instance of GroupsCountResult.
911 912 913 |
# File 'lib/google/apis/vault_v1/classes.rb', line 911 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_count_errors ⇒ Array<Google::Apis::VaultV1::AccountCountError>
Error occurred when querying these accounts.
Corresponds to the JSON property accountCountErrors
887 888 889 |
# File 'lib/google/apis/vault_v1/classes.rb', line 887 def account_count_errors @account_count_errors end |
#account_counts ⇒ Array<Google::Apis::VaultV1::AccountCount>
Subtotal count per matching account that have more than zero messages.
Corresponds to the JSON property accountCounts
892 893 894 |
# File 'lib/google/apis/vault_v1/classes.rb', line 892 def account_counts @account_counts end |
#matching_accounts_count ⇒ Fixnum
Total number of accounts that can be queried and have more than zero messages.
Corresponds to the JSON property matchingAccountsCount
897 898 899 |
# File 'lib/google/apis/vault_v1/classes.rb', line 897 def matching_accounts_count @matching_accounts_count end |
#non_queryable_accounts ⇒ Array<String>
When DataScope is HELD_DATA, these accounts in the request are not
queried because they are not on hold. For other data scope, this field is not
set.
Corresponds to the JSON property nonQueryableAccounts
904 905 906 |
# File 'lib/google/apis/vault_v1/classes.rb', line 904 def non_queryable_accounts @non_queryable_accounts end |
#queried_accounts_count ⇒ Fixnum
Total number of accounts involved in this count operation.
Corresponds to the JSON property queriedAccountsCount
909 910 911 |
# File 'lib/google/apis/vault_v1/classes.rb', line 909 def queried_accounts_count @queried_accounts_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
916 917 918 919 920 921 922 |
# File 'lib/google/apis/vault_v1/classes.rb', line 916 def update!(**args) @account_count_errors = args[:account_count_errors] if args.key?(:account_count_errors) @account_counts = args[:account_counts] if args.key?(:account_counts) @matching_accounts_count = args[:matching_accounts_count] if args.key?(:matching_accounts_count) @non_queryable_accounts = args[:non_queryable_accounts] if args.key?(:non_queryable_accounts) @queried_accounts_count = args[:queried_accounts_count] if args.key?(:queried_accounts_count) end |