Class: Google::Apis::VaultV1::HeldAccount
- Inherits:
-
Object
- Object
- Google::Apis::VaultV1::HeldAccount
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vault_v1/classes.rb,
lib/google/apis/vault_v1/representations.rb,
lib/google/apis/vault_v1/representations.rb
Overview
An account covered by a hold. This structure is immutable. It can be an individual account or a Google Group, depending on the service. To work with Vault resources, the account must have the required Vault privileges and access to the matter. To access a matter, the account must have created the matter, have the matter shared with them, or have the View All Matters privilege.
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account ID, as provided by the Admin SDK.
-
#email ⇒ String
The primary email address of the account.
-
#first_name ⇒ String
Output only.
-
#hold_time ⇒ String
Output only.
-
#last_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HeldAccount
constructor
A new instance of HeldAccount.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HeldAccount
Returns a new instance of HeldAccount.
1035 1036 1037 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1035 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ String
The account ID, as provided by the Admin SDK.
Corresponds to the JSON property accountId
1012 1013 1014 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1012 def account_id @account_id end |
#email ⇒ String
The primary email address of the account. If used as an input, this takes
precedence over accountId.
Corresponds to the JSON property email
1018 1019 1020 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1018 def email @email end |
#first_name ⇒ String
Output only. The first name of the account holder.
Corresponds to the JSON property firstName
1023 1024 1025 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1023 def first_name @first_name end |
#hold_time ⇒ String
Output only. When the account was put on hold.
Corresponds to the JSON property holdTime
1028 1029 1030 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1028 def hold_time @hold_time end |
#last_name ⇒ String
Output only. The last name of the account holder.
Corresponds to the JSON property lastName
1033 1034 1035 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1033 def last_name @last_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1040 1041 1042 1043 1044 1045 1046 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1040 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @email = args[:email] if args.key?(:email) @first_name = args[:first_name] if args.key?(:first_name) @hold_time = args[:hold_time] if args.key?(:hold_time) @last_name = args[:last_name] if args.key?(:last_name) end |