Class: Google::Apis::VaultV1::ListHoldsResponse
- Inherits:
-
Object
- Object
- Google::Apis::VaultV1::ListHoldsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vault_v1/classes.rb,
lib/google/apis/vault_v1/representations.rb,
lib/google/apis/vault_v1/representations.rb
Overview
The holds for a matter.
Instance Attribute Summary collapse
-
#holds ⇒ Array<Google::Apis::VaultV1::Hold>
The list of holds.
-
#next_page_token ⇒ String
Page token to retrieve the next page of results in the list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListHoldsResponse
constructor
A new instance of ListHoldsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListHoldsResponse
Returns a new instance of ListHoldsResponse.
1362 1363 1364 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1362 def initialize(**args) update!(**args) end |
Instance Attribute Details
#holds ⇒ Array<Google::Apis::VaultV1::Hold>
The list of holds.
Corresponds to the JSON property holds
1354 1355 1356 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1354 def holds @holds end |
#next_page_token ⇒ String
Page token to retrieve the next page of results in the list. If this is empty,
then there are no more holds to list.
Corresponds to the JSON property nextPageToken
1360 1361 1362 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1360 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1367 1368 1369 1370 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1367 def update!(**args) @holds = args[:holds] if args.key?(:holds) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |