Class: Google::Apis::VaultV1::ListHoldsResponse
- Inherits:
-
Object
- Object
- Google::Apis::VaultV1::ListHoldsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vault_v1/classes.rb,
lib/google/apis/vault_v1/representations.rb,
lib/google/apis/vault_v1/representations.rb
Overview
The holds for a matter.
Instance Attribute Summary collapse
-
#holds ⇒ Array<Google::Apis::VaultV1::Hold>
The list of holds.
-
#next_page_token ⇒ String
Page token to retrieve the next page of results in the list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListHoldsResponse
constructor
A new instance of ListHoldsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListHoldsResponse
Returns a new instance of ListHoldsResponse.
1343 1344 1345 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1343 def initialize(**args) update!(**args) end |
Instance Attribute Details
#holds ⇒ Array<Google::Apis::VaultV1::Hold>
The list of holds.
Corresponds to the JSON property holds
1335 1336 1337 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1335 def holds @holds end |
#next_page_token ⇒ String
Page token to retrieve the next page of results in the list. If this is empty,
then there are no more holds to list.
Corresponds to the JSON property nextPageToken
1341 1342 1343 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1341 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1348 1349 1350 1351 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1348 def update!(**args) @holds = args[:holds] if args.key?(:holds) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |