Class: Google::Apis::VaultV1::ListSavedQueriesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vault_v1/classes.rb,
lib/google/apis/vault_v1/representations.rb,
lib/google/apis/vault_v1/representations.rb

Overview

Definition of the response for method ListSaveQuery.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListSavedQueriesResponse

Returns a new instance of ListSavedQueriesResponse.



1428
1429
1430
# File 'lib/google/apis/vault_v1/classes.rb', line 1428

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Page token to retrieve the next page of results in the list. If this is empty, then there are no more saved queries to list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1421
1422
1423
# File 'lib/google/apis/vault_v1/classes.rb', line 1421

def next_page_token
  @next_page_token
end

#saved_queriesArray<Google::Apis::VaultV1::SavedQuery>

List of saved queries. Corresponds to the JSON property savedQueries



1426
1427
1428
# File 'lib/google/apis/vault_v1/classes.rb', line 1426

def saved_queries
  @saved_queries
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1433
1434
1435
1436
# File 'lib/google/apis/vault_v1/classes.rb', line 1433

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @saved_queries = args[:saved_queries] if args.key?(:saved_queries)
end