Class: Google::Apis::VaultV1::MailCountResult
- Inherits:
-
Object
- Object
- Google::Apis::VaultV1::MailCountResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vault_v1/classes.rb,
lib/google/apis/vault_v1/representations.rb,
lib/google/apis/vault_v1/representations.rb
Overview
Gmail and classic Hangouts-specific count metrics.
Instance Attribute Summary collapse
-
#account_count_errors ⇒ Array<Google::Apis::VaultV1::AccountCountError>
Errors occurred when querying these accounts.
-
#account_counts ⇒ Array<Google::Apis::VaultV1::AccountCount>
Subtotal count per matching account that have more than zero messages.
-
#matching_accounts_count ⇒ Fixnum
Total number of accounts that can be queried and have more than zero messages.
-
#non_queryable_accounts ⇒ Array<String>
When DataScope is HELD_DATA and when account emails are passed in explicitly, the list of accounts in the request that are not queried because they are not on hold in the matter.
-
#queried_accounts_count ⇒ Fixnum
Total number of accounts involved in this count operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MailCountResult
constructor
A new instance of MailCountResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MailCountResult
Returns a new instance of MailCountResult.
1490 1491 1492 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1490 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_count_errors ⇒ Array<Google::Apis::VaultV1::AccountCountError>
Errors occurred when querying these accounts.
Corresponds to the JSON property accountCountErrors
1465 1466 1467 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1465 def account_count_errors @account_count_errors end |
#account_counts ⇒ Array<Google::Apis::VaultV1::AccountCount>
Subtotal count per matching account that have more than zero messages.
Corresponds to the JSON property accountCounts
1470 1471 1472 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1470 def account_counts @account_counts end |
#matching_accounts_count ⇒ Fixnum
Total number of accounts that can be queried and have more than zero messages.
Corresponds to the JSON property matchingAccountsCount
1475 1476 1477 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1475 def matching_accounts_count @matching_accounts_count end |
#non_queryable_accounts ⇒ Array<String>
When DataScope is HELD_DATA and when account emails are passed in
explicitly, the list of accounts in the request that are not queried because
they are not on hold in the matter. For other data scopes, this field is not
set.
Corresponds to the JSON property nonQueryableAccounts
1483 1484 1485 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1483 def non_queryable_accounts @non_queryable_accounts end |
#queried_accounts_count ⇒ Fixnum
Total number of accounts involved in this count operation.
Corresponds to the JSON property queriedAccountsCount
1488 1489 1490 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1488 def queried_accounts_count @queried_accounts_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1495 1496 1497 1498 1499 1500 1501 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1495 def update!(**args) @account_count_errors = args[:account_count_errors] if args.key?(:account_count_errors) @account_counts = args[:account_counts] if args.key?(:account_counts) @matching_accounts_count = args[:matching_accounts_count] if args.key?(:matching_accounts_count) @non_queryable_accounts = args[:non_queryable_accounts] if args.key?(:non_queryable_accounts) @queried_accounts_count = args[:queried_accounts_count] if args.key?(:queried_accounts_count) end |