Class: Google::Apis::VaultV1::MailCountResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vault_v1/classes.rb,
lib/google/apis/vault_v1/representations.rb,
lib/google/apis/vault_v1/representations.rb

Overview

Gmail and classic Hangouts-specific count metrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MailCountResult

Returns a new instance of MailCountResult.



1471
1472
1473
# File 'lib/google/apis/vault_v1/classes.rb', line 1471

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_count_errorsArray<Google::Apis::VaultV1::AccountCountError>

Errors occurred when querying these accounts. Corresponds to the JSON property accountCountErrors



1446
1447
1448
# File 'lib/google/apis/vault_v1/classes.rb', line 1446

def 
  @account_count_errors
end

#account_countsArray<Google::Apis::VaultV1::AccountCount>

Subtotal count per matching account that have more than zero messages. Corresponds to the JSON property accountCounts



1451
1452
1453
# File 'lib/google/apis/vault_v1/classes.rb', line 1451

def 
  @account_counts
end

#matching_accounts_countFixnum

Total number of accounts that can be queried and have more than zero messages. Corresponds to the JSON property matchingAccountsCount

Returns:

  • (Fixnum)


1456
1457
1458
# File 'lib/google/apis/vault_v1/classes.rb', line 1456

def matching_accounts_count
  @matching_accounts_count
end

#non_queryable_accountsArray<String>

When DataScope is HELD_DATA and when account emails are passed in explicitly, the list of accounts in the request that are not queried because they are not on hold in the matter. For other data scopes, this field is not set. Corresponds to the JSON property nonQueryableAccounts

Returns:

  • (Array<String>)


1464
1465
1466
# File 'lib/google/apis/vault_v1/classes.rb', line 1464

def non_queryable_accounts
  @non_queryable_accounts
end

#queried_accounts_countFixnum

Total number of accounts involved in this count operation. Corresponds to the JSON property queriedAccountsCount

Returns:

  • (Fixnum)


1469
1470
1471
# File 'lib/google/apis/vault_v1/classes.rb', line 1469

def queried_accounts_count
  @queried_accounts_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1476
1477
1478
1479
1480
1481
1482
# File 'lib/google/apis/vault_v1/classes.rb', line 1476

def update!(**args)
  @account_count_errors = args[:account_count_errors] if args.key?(:account_count_errors)
  @account_counts = args[:account_counts] if args.key?(:account_counts)
  @matching_accounts_count = args[:matching_accounts_count] if args.key?(:matching_accounts_count)
  @non_queryable_accounts = args[:non_queryable_accounts] if args.key?(:non_queryable_accounts)
  @queried_accounts_count = args[:queried_accounts_count] if args.key?(:queried_accounts_count)
end