Class: Google::Apis::VaultV1::Matter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vault_v1/classes.rb,
lib/google/apis/vault_v1/representations.rb,
lib/google/apis/vault_v1/representations.rb

Overview

Represents a matter. To work with Vault resources, the account must have the required Vault privileges and access to the matter. To access a matter, the account must have created the matter, have the matter shared with them, or have the View All Matters privilege.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Matter

Returns a new instance of Matter.



1592
1593
1594
# File 'lib/google/apis/vault_v1/classes.rb', line 1592

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

An optional description for the matter. Corresponds to the JSON property description

Returns:

  • (String)


1563
1564
1565
# File 'lib/google/apis/vault_v1/classes.rb', line 1563

def description
  @description
end

#matter_idString

The matter ID, which is generated by the server. Leave blank when creating a matter. Corresponds to the JSON property matterId

Returns:

  • (String)


1569
1570
1571
# File 'lib/google/apis/vault_v1/classes.rb', line 1569

def matter_id
  @matter_id
end

#matter_permissionsArray<Google::Apis::VaultV1::MatterPermission>

Lists the users and their permission for the matter. Currently there is no programmer defined limit on the number of permissions a matter can have. Corresponds to the JSON property matterPermissions



1575
1576
1577
# File 'lib/google/apis/vault_v1/classes.rb', line 1575

def matter_permissions
  @matter_permissions
end

#matter_regionString

Optional. The requested data region for the matter. Corresponds to the JSON property matterRegion

Returns:

  • (String)


1580
1581
1582
# File 'lib/google/apis/vault_v1/classes.rb', line 1580

def matter_region
  @matter_region
end

#nameString

The name of the matter. Corresponds to the JSON property name

Returns:

  • (String)


1585
1586
1587
# File 'lib/google/apis/vault_v1/classes.rb', line 1585

def name
  @name
end

#stateString

The state of the matter. Corresponds to the JSON property state

Returns:

  • (String)


1590
1591
1592
# File 'lib/google/apis/vault_v1/classes.rb', line 1590

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1597
1598
1599
1600
1601
1602
1603
1604
# File 'lib/google/apis/vault_v1/classes.rb', line 1597

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @matter_id = args[:matter_id] if args.key?(:matter_id)
  @matter_permissions = args[:matter_permissions] if args.key?(:matter_permissions)
  @matter_region = args[:matter_region] if args.key?(:matter_region)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end