Class: Google::Apis::VaultV1::SavedQuery
- Inherits:
-
Object
- Object
- Google::Apis::VaultV1::SavedQuery
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vault_v1/classes.rb,
lib/google/apis/vault_v1/representations.rb,
lib/google/apis/vault_v1/representations.rb
Overview
The definition of a saved query. To work with Vault resources, the account must have the required Vault privileges and access to the matter. To access a matter, the account must have created the matter, have the matter shared with them, or have the View All Matters privilege.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
The name of the saved query.
-
#matter_id ⇒ String
Output only.
-
#query ⇒ Google::Apis::VaultV1::Query
The query definition used for search and export.
-
#saved_query_id ⇒ String
A unique identifier for the saved query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SavedQuery
constructor
A new instance of SavedQuery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SavedQuery
Returns a new instance of SavedQuery.
2013 2014 2015 |
# File 'lib/google/apis/vault_v1/classes.rb', line 2013 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The server-generated timestamp when the saved query was created.
Corresponds to the JSON property createTime
1989 1990 1991 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1989 def create_time @create_time end |
#display_name ⇒ String
The name of the saved query.
Corresponds to the JSON property displayName
1994 1995 1996 |
# File 'lib/google/apis/vault_v1/classes.rb', line 1994 def display_name @display_name end |
#matter_id ⇒ String
Output only. The matter ID of the matter the saved query is saved in. The
server does not use this field during create and always uses matter ID in the
URL.
Corresponds to the JSON property matterId
2001 2002 2003 |
# File 'lib/google/apis/vault_v1/classes.rb', line 2001 def matter_id @matter_id end |
#query ⇒ Google::Apis::VaultV1::Query
The query definition used for search and export.
Corresponds to the JSON property query
2006 2007 2008 |
# File 'lib/google/apis/vault_v1/classes.rb', line 2006 def query @query end |
#saved_query_id ⇒ String
A unique identifier for the saved query.
Corresponds to the JSON property savedQueryId
2011 2012 2013 |
# File 'lib/google/apis/vault_v1/classes.rb', line 2011 def saved_query_id @saved_query_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2018 2019 2020 2021 2022 2023 2024 |
# File 'lib/google/apis/vault_v1/classes.rb', line 2018 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @matter_id = args[:matter_id] if args.key?(:matter_id) @query = args[:query] if args.key?(:query) @saved_query_id = args[:saved_query_id] if args.key?(:saved_query_id) end |